summaryrefslogtreecommitdiffhomepage
path: root/Kernel/Sources/LockDelegate.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Kernel/Sources/LockDelegate.cxx')
-rw-r--r--Kernel/Sources/LockDelegate.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/Kernel/Sources/LockDelegate.cxx b/Kernel/Sources/LockDelegate.cxx
index e2134f60..6f0aa1d4 100644
--- a/Kernel/Sources/LockDelegate.cxx
+++ b/Kernel/Sources/LockDelegate.cxx
@@ -6,7 +6,7 @@
#include <KernelKit/LockDelegate.hpp>
-namespace NewOS
+namespace Kernel
{
/// Leave it empty for now.
-} // namespace NewOS \ No newline at end of file
+} // namespace Kernel \ No newline at end of file